<?php /** @noinspection PhpUndefinedMethodInspection */
/** @noinspection PhpParamsInspection */
declare(strict_types=1);

namespace IntiTest\Wp\Middleware;

use Inti\Wp\Plugin\Service\PluginRunner;
use Inti\Wp\Plugin\Service\PluginRunnerInterface;
use PHPUnit\Framework\TestCase;
use Prophecy\PhpUnit\ProphecyTrait;
use Prophecy\Prophecy\ObjectProphecy;

use function defined;

/**
 * Class BootstrapTest
 *
 * @package IntiTest\Wp\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-middleware
 *
 * @runTestsInSeparateProcesses
 */
final class BootstrapTest extends TestCase
{
    use WordPressTestCase;
    use ProphecyTrait;

    protected function setUp(): void
    {
        $this->setUpContainer();
        $this->setUpWordPress();
    }

    public function testBootstrapWillDeclareConfigConstants()
    {
        $this->runApplication();

        $this->assertTrue(defined('DB_HOST'));
        $this->assertEquals('localhost', DB_HOST);

        $this->assertTrue(defined('WP_HOME'));
        $this->assertEquals('http://inti.dev', WP_HOME);
        $this->assertEquals('http://inti.dev/wordpress', WP_SITEURL);
        $this->assertEquals(ABSPATH . 'wp-content', WP_CONTENT_DIR);
        $this->assertEquals('http://inti.dev/wordpress/wp-content', WP_CONTENT_URL);
    }

    public function testBootstrapWillRunPlugins()
    {
        $plugins = ['some-plugin'];

        /** @var PluginRunner|ObjectProphecy $runner */
        $runner = $this->prophesize(PluginRunnerInterface::class);
        $runner->run($plugins)->shouldBeCalled();

        $this->runApplication([
            'wp' => [
                'plugins' => $plugins,
            ],
            'dependencies' => [
                'services' => [
                    PluginRunnerInterface::class => $runner->reveal(),
                ],
            ],
        ]);
    }

    public function testWillRegisterGlobals()
    {
        $this->runApplication([
            'wp' => [
                'globals' => [
                    'some_global',
                ],
            ],
        ]);

        $this->assertArrayHasKey('some_global', $GLOBALS);
    }
}
