<?php
declare(strict_types=1);

namespace IntiTest\Wp\Middleware\Handler;

use IntiTest\Wp\Middleware\WordPressTestCase;
use PHPUnit\Framework\TestCase;
use function define;
use function did_action;

/**
 * Class IndexTest
 *
 * @package IntiTest\Wp\Middleware\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-middleware
 */
final class IndexTest extends TestCase
{
    use WordPressTestCase;

    protected function setUp(): void
    {
        $this->setUpContainer();
        $this->setUpWordPress();
    }

    public function testWillReturnEmptyResponseForNonThemeRequest()
    {
        $response = $this->runApplication();

        $this->assertEquals(200, $response->getStatusCode());
        $this->assertEmpty($response->getHeaders());
        $this->assertEmpty($response->getBody()->getContents());
    }

    public function testWillRenderThemeForThemeRequests()
    {
        define('WP_USE_THEMES', true);
        $response = $this->runApplication();

        $this->assertEquals(1, did_action('template_redirect'));

        $this->assertEquals(200, $response->getStatusCode());
        $this->assertEquals('text/html; charset=utf-8', $response->getHeaderLine('Content-Type'));
        $this->assertStringContainsString('<meta name="generator" content="WordPress', $response->getBody()->getContents());
    }
}
