<?php
declare(strict_types=1);

namespace IntiTest\Wp\Middleware;

use Doctrine\DBAL\Exception;
use DomainException;
use Inti\Db\Connection\ConnectionManager;
use Inti\Test\TestCase\ApplicationTestCase;
use Inti\Wp\Middleware\ConfigProvider;

trait WordPressTestCase
{
    use ApplicationTestCase;

    protected array $providers = [
        \Mezzio\Router\FastRouteRouter\ConfigProvider::class,
        \Inti\App\ConfigProvider::class,
        \Inti\Db\ConfigProvider::class,
        \Inti\Wp\Plugin\ConfigProvider::class,
        ConfigProvider::class,
    ];

    protected array $config = [
        'db_connections' => [
            'default' => [
                'host' => 'localhost',
                'user' => 'root',
                'password' => 'password',
                'dbname' => 'inti_wp_middleware',
            ],
        ],
    ];

    protected function setUpWordPress(): void
    {
        if (!defined('ABSPATH')) {
            define('ABSPATH', realpath(__DIR__ . '/../wordpress') . '/');
        }

        $container = $this->createContainer();
        /** @var ConnectionManager $connectionManager */
        $connectionManager = $container->get(ConnectionManager::class);
        $conn = $connectionManager->get('default');
        $this->container = null;

        try {
            $conn->executeQuery('SELECT option_value FROM wp_options WHERE option_name = ?', ['siteurl']);
        } catch (Exception $e) {
            throw new DomainException(sprintf(
                '%s: WordPress must be installed.',
                __METHOD__
            ));
        }
    }
}
